package com.ycwl.basic.controller.mobile;

import com.github.pagehelper.PageInfo;
import com.ycwl.basic.annotation.IgnoreToken;
import com.ycwl.basic.constant.BaseContextHandler;
import com.ycwl.basic.model.jwt.JwtInfo;
import com.ycwl.basic.model.mobile.goods.GoodsPageVO;
import com.ycwl.basic.model.mobile.goods.GoodsReqQuery;
import com.ycwl.basic.model.mobile.scenic.ScenicAppVO;
import com.ycwl.basic.model.mobile.scenic.ScenicDeviceCountVO;
import com.ycwl.basic.model.mobile.scenic.content.ContentPageVO;
import com.ycwl.basic.model.pc.scenic.entity.ScenicConfigEntity;
import com.ycwl.basic.model.pc.scenic.req.ScenicReqQuery;
import com.ycwl.basic.model.pc.scenic.resp.ScenicRespVO;
import com.ycwl.basic.repository.ScenicRepository;
import com.ycwl.basic.service.mobile.AppScenicService;
import com.ycwl.basic.service.pc.ScenicService;
import com.ycwl.basic.utils.ApiResponse;
import com.ycwl.basic.utils.JwtTokenUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Author：longbinbin
 * @Date：2024/12/5 10:22
 */
@Slf4j
@RestController
@RequestMapping("/api/mobile/scenic/v1")
@Api(tags = "景区相关接口")
public class AppScenicController {

    @Autowired
    private AppScenicService appScenicService;
    @Autowired
    private ScenicRepository scenicRepository;

    @ApiOperation("分页查询景区列表")
    @PostMapping("/page")
    public ApiResponse<PageInfo<ScenicAppVO>> pageQuery(@RequestBody ScenicReqQuery scenicReqQuery){
        return appScenicService.pageQuery(scenicReqQuery);
    }
    @ApiOperation("根据id查询景区详情")
    @IgnoreToken
    @GetMapping("/{id}")
    public ApiResponse<ScenicRespVO> getDetails(@PathVariable Long id){
        return appScenicService.getDetails(id);
    }

    @GetMapping("/{id}/config")
    @IgnoreToken
    public ApiResponse<ScenicConfigEntity> getConfig(@PathVariable Long id){
        ScenicConfigEntity scenicConfig = scenicRepository.getScenicConfig(id);
        return ApiResponse.success(scenicConfig);
    }

    @ApiOperation("查询景区设备总数和拍到用户的机位数量")
    @GetMapping("/{scenicId}/deviceCount/")
    public ApiResponse<ScenicDeviceCountVO> deviceCountByScenicId(@PathVariable Long scenicId){
        return appScenicService.deviceCountByScenicId(scenicId);
    }

    @ApiOperation("景区视频源素材列表")
    @GetMapping("/contentList/")
    public ApiResponse<List<ContentPageVO>> contentList() {
        return appScenicService.contentListUseDefaultFace();
    }

    @ApiOperation("景区视频源素材列表")
    @GetMapping("/face/{faceId}/contentList")
    public ApiResponse<List<ContentPageVO>> contentList(@PathVariable String faceId) {
        if (!StringUtils.isNumeric(faceId)) {
            log.error("请求异常, faceId: [{}]",faceId);
            return ApiResponse.fail("请求异常");
        }
        Long id = Long.parseLong(faceId);
        JwtInfo worker = JwtTokenUtil.getWorker();
        List<ContentPageVO> contentPageVOS = appScenicService.faceContentList(worker.getUserId(), id);
        return  ApiResponse.success(contentPageVOS);
    }


}
